diff --git a/boards/uniboard1/designs/unb1_minimal/hdllib.cfg b/boards/uniboard1/designs/unb1_minimal/hdllib.cfg
index 4cd7be3808e534192768bfb2bb1aab810f09080b..d4f93e8cd3968e20211b661c43c20fc920889731 100644
--- a/boards/uniboard1/designs/unb1_minimal/hdllib.cfg
+++ b/boards/uniboard1/designs/unb1_minimal/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = unb1_minimal_lib
 hdl_lib_uses = common mm i2c unb1_board
 hdl_lib_technology = ip_stratixiv
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     $HDL_BUILD_DIR/quartus/unb1_minimal/sopc_unb1_minimal.vhd
@@ -17,7 +17,7 @@ test_bench_files =
 synth_top_level_entity =
 synth_revision = 
 
-synth_copy_files =
+quartus_copy_files =
     quartus/sopc_unb1_minimal.sopc .
 
 quartus_qsf_files =
diff --git a/boards/uniboard1/designs/unb1_test/hdllib.cfg b/boards/uniboard1/designs/unb1_test/hdllib.cfg
index 5e3b415a7a878e1ef6a27a83d8525dda64005750..bbc183d04ab4dae3197ab6b41087946d6197b032 100644
--- a/boards/uniboard1/designs/unb1_test/hdllib.cfg
+++ b/boards/uniboard1/designs/unb1_test/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = unb1_test_lib
 hdl_lib_uses = common mm i2c unb1_board remu epcs dp eth tr_xaui tr_10GbE mdio diagnostics
 hdl_lib_technology = ip_stratixiv
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     $HDL_BUILD_DIR/quartus/unb1_test/sopc_unb1_test.vhd
@@ -17,7 +17,7 @@ test_bench_files =
 synth_top_level_entity =
 synth_revision = 
 
-synth_copy_files =
+quartus_copy_files =
     quartus/sopc_unb1_test.sopc .
 
 quartus_qsf_files =
diff --git a/boards/uniboard1/libraries/unb1_board/hdllib.cfg b/boards/uniboard1/libraries/unb1_board/hdllib.cfg
index 265bfced2ced8905616649f161d4e3fe83643545..bd5f0442b70feb37bb1ab7ef1ba257c630ee6be6 100644
--- a/boards/uniboard1/libraries/unb1_board/hdllib.cfg
+++ b/boards/uniboard1/libraries/unb1_board/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = unb1_board_lib
 hdl_lib_uses = common dp diag uth ppsh i2c tr_nonbonded eth remu
 hdl_lib_technology = ip_stratixiv
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     $UNB/Firmware/designs/unb_common/../../modules/MegaWizard/pll/clk200_pll.vhd
diff --git a/libraries/base/common/hdllib.cfg b/libraries/base/common/hdllib.cfg
index c9661b10f2b3fce3d6087c31343966eaf8718791..68770a1367549ddc65e0d3b502733a1d65f85429 100644
--- a/libraries/base/common/hdllib.cfg
+++ b/libraries/base/common/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = common_lib
 hdl_lib_uses = technology tech_memory tech_fifo tech_iobuf tst
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     $UNB/Firmware/modules/common/src/vhdl/common_pkg.vhd
diff --git a/libraries/base/diag/hdllib.cfg b/libraries/base/diag/hdllib.cfg
index bb473f0167b31c3df6cab66eb931862c07b49844..06595cdf39a97e375a4ad0d80c30add886130538 100644
--- a/libraries/base/diag/hdllib.cfg
+++ b/libraries/base/diag/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = diag_lib
 hdl_lib_uses = dp common
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     $UNB/Firmware/modules/Lofar/diag/src/vhdl/diag_bypass.vhd
diff --git a/libraries/base/diagnostics/hdllib.cfg b/libraries/base/diagnostics/hdllib.cfg
index 4b14b7c9cee2ec52b5680a844ad7ed8f638d6885..b87bc14b5b5cdb45921b9b204e0392c7ef76856f 100644
--- a/libraries/base/diagnostics/hdllib.cfg
+++ b/libraries/base/diagnostics/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = diagnostics_lib
 hdl_lib_uses = common dp diag
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     $UNB/Firmware/modules/diagnostics/src/vhdl/diagnostics.vhd
diff --git a/libraries/base/dp/hdllib.cfg b/libraries/base/dp/hdllib.cfg
index 05d98b0d0dac1a10ac573b95b6982476c63a2ccb..67095213014204a935090e8b042f35ec8ebb9968 100644
--- a/libraries/base/dp/hdllib.cfg
+++ b/libraries/base/dp/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = dp_lib
 hdl_lib_uses = mm common easics
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     $UNB/Firmware/modules/dp/src/vhdl/dp_stream_pkg.vhd
diff --git a/libraries/base/mm/hdllib.cfg b/libraries/base/mm/hdllib.cfg
index fbaadc91164bd228936305c327c391cbaf76a8e5..8692715ab7f0d90fd0b765e9c95ecfec5f00cf5d 100644
--- a/libraries/base/mm/hdllib.cfg
+++ b/libraries/base/mm/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = mm_lib
 hdl_lib_uses = common
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     $UNB/Firmware/modules/mm/src/vhdl/mm_fields.vhd
diff --git a/libraries/base/sens/hdllib.cfg b/libraries/base/sens/hdllib.cfg
index 529c44aee5e652d33a7e4447af00224eda9a1dff..76b7056aa2eb8cc36d93c06298654e622c7e1436 100644
--- a/libraries/base/sens/hdllib.cfg
+++ b/libraries/base/sens/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = sens_lib
 hdl_lib_uses = common i2c
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     $UNB/Firmware/modules/Lofar/sens/src/vhdl/sens_ctrl.vhd
diff --git a/libraries/base/tst/hdllib.cfg b/libraries/base/tst/hdllib.cfg
index 2847571d0bb0c3e79a621d7fb5604451c5aa937f..da5e50750568ef729ef6be7efe892e7b399736a7 100644
--- a/libraries/base/tst/hdllib.cfg
+++ b/libraries/base/tst/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = tst_lib
 hdl_lib_uses = 
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     $UNB/Firmware/modules/Lofar/tst/src/vhdl/tst_output.vhd
diff --git a/libraries/base/uth/hdllib.cfg b/libraries/base/uth/hdllib.cfg
index 08e271fd9e7789c8cecdc8d84c25a9ab38b26f6f..61353c203cde86518279d366c08cc76a66ea7295 100644
--- a/libraries/base/uth/hdllib.cfg
+++ b/libraries/base/uth/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = uth_lib
 hdl_lib_uses = common dp easics
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     $UNB/Firmware/modules/uth/src/vhdl/uth_pkg.vhd
diff --git a/libraries/external/easics/hdllib.cfg b/libraries/external/easics/hdllib.cfg
index b484477a7d95c333ea5068c16692412b961d5e92..8675630267743ca096b644010ab605ac284042b7 100644
--- a/libraries/external/easics/hdllib.cfg
+++ b/libraries/external/easics/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = easics_lib
 hdl_lib_uses = 
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     $UNB/Firmware/modules/easics/src/vhdl/PCK_CRC64_D8.vhd
diff --git a/libraries/external/numonyx_m25p128/hdllib.cfg b/libraries/external/numonyx_m25p128/hdllib.cfg
index d44dfd79842cd8dff3c615edfad80f6c1c0ceda1..e8fb221b646fefa5b6069e23546a523c3e72c256 100644
--- a/libraries/external/numonyx_m25p128/hdllib.cfg
+++ b/libraries/external/numonyx_m25p128/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = numonyx_m25p128_lib
 hdl_lib_uses = 
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     
diff --git a/libraries/io/epcs/hdllib.cfg b/libraries/io/epcs/hdllib.cfg
index 862eab1cb1e3da50934a60d97f31b40fef39269f..8ac8fc955379c1a55b4eb5b02dd86ad0a6f16824 100644
--- a/libraries/io/epcs/hdllib.cfg
+++ b/libraries/io/epcs/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = epcs_lib
 hdl_lib_uses = common dp tech_flash
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     $UNB/Firmware/modules/epcs/src/vhdl/epcs_reg.vhd
diff --git a/libraries/io/eth/hdllib.cfg b/libraries/io/eth/hdllib.cfg
index eca3c239523e3f8fd901be4fdcc70a5a99ee5ff9..f06551b259da9d9316f92251c4b3445a1f032ac7 100644
--- a/libraries/io/eth/hdllib.cfg
+++ b/libraries/io/eth/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = eth_lib
 hdl_lib_uses = dp common tech_tse
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir= $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     src/vhdl/eth_pkg.vhd
diff --git a/libraries/io/i2c/hdllib.cfg b/libraries/io/i2c/hdllib.cfg
index e0272fff8d3d4d796dd56db9319c0e64e20da7e4..d911550c2f25fa8d4b510caa14a06abaed48a33f 100644
--- a/libraries/io/i2c/hdllib.cfg
+++ b/libraries/io/i2c/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = i2c_lib
 hdl_lib_uses = common
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     $UNB/Firmware/modules/Lofar/i2c/src/vhdl/i2c_pkg.vhd
diff --git a/libraries/io/mdio/hdllib.cfg b/libraries/io/mdio/hdllib.cfg
index 28323e8d9e0e69d5a573764fbeadcd2e416f13eb..0cb8a9f188d56bde9d09e695bea66021e9b98a3d 100644
--- a/libraries/io/mdio/hdllib.cfg
+++ b/libraries/io/mdio/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = mdio_lib
 hdl_lib_uses = common mm
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = 
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = 
 
 synth_files =
     $UNB/Firmware/modules/Lofar/mdio/src/vhdl/mdio_pkg.vhd
diff --git a/libraries/io/mdio/quartus/mdio_lib.qip b/libraries/io/mdio/quartus/mdio_lib.qip
index 1197b6760aad75a21c0ec8057b650ea2fb791694..c843c2ab85351aa3adeab1fe36ae604ce7e0d363 100644
--- a/libraries/io/mdio/quartus/mdio_lib.qip
+++ b/libraries/io/mdio/quartus/mdio_lib.qip
@@ -1,9 +1,9 @@
 # synth_files
-set_global_assignment -name VHDL_FILE /home/hiemstra/svn/UniBoard_FP7/UniBoard/trunk/Firmware/modules/Lofar/mdio/src/vhdl/mdio_pkg.vhd
-set_global_assignment -name VHDL_FILE /home/hiemstra/svn/UniBoard_FP7/UniBoard/trunk/Firmware/modules/Lofar/mdio/src/vhdl/mdio_mm.vhd
-set_global_assignment -name VHDL_FILE /home/hiemstra/svn/UniBoard_FP7/UniBoard/trunk/Firmware/modules/Lofar/mdio/src/vhdl/mdio_ctlr.vhd
-set_global_assignment -name VHDL_FILE /home/hiemstra/svn/UniBoard_FP7/UniBoard/trunk/Firmware/modules/Lofar/mdio/src/vhdl/mdio_phy_reg.vhd
-set_global_assignment -name VHDL_FILE /home/hiemstra/svn/UniBoard_FP7/UniBoard/trunk/Firmware/modules/Lofar/mdio/src/vhdl/mdio_phy.vhd
-set_global_assignment -name VHDL_FILE /home/hiemstra/svn/UniBoard_FP7/UniBoard/trunk/Firmware/modules/Lofar/mdio/src/vhdl/mdio_vitesse_vsc8486_pkg.vhd
-set_global_assignment -name VHDL_FILE /home/hiemstra/svn/UniBoard_FP7/UniBoard/trunk/Firmware/modules/Lofar/mdio/src/vhdl/mdio.vhd
-set_global_assignment -name VHDL_FILE /home/hiemstra/svn/UniBoard_FP7/UniBoard/trunk/Firmware/modules/Lofar/mdio/src/vhdl/avs_mdio.vhd
+set_global_assignment -name VHDL_FILE /home/kooistra/svnroot/UniBoard_FP7/UniBoard/trunk/Firmware/modules/Lofar/mdio/src/vhdl/mdio_pkg.vhd
+set_global_assignment -name VHDL_FILE /home/kooistra/svnroot/UniBoard_FP7/UniBoard/trunk/Firmware/modules/Lofar/mdio/src/vhdl/mdio_mm.vhd
+set_global_assignment -name VHDL_FILE /home/kooistra/svnroot/UniBoard_FP7/UniBoard/trunk/Firmware/modules/Lofar/mdio/src/vhdl/mdio_ctlr.vhd
+set_global_assignment -name VHDL_FILE /home/kooistra/svnroot/UniBoard_FP7/UniBoard/trunk/Firmware/modules/Lofar/mdio/src/vhdl/mdio_phy_reg.vhd
+set_global_assignment -name VHDL_FILE /home/kooistra/svnroot/UniBoard_FP7/UniBoard/trunk/Firmware/modules/Lofar/mdio/src/vhdl/mdio_phy.vhd
+set_global_assignment -name VHDL_FILE /home/kooistra/svnroot/UniBoard_FP7/UniBoard/trunk/Firmware/modules/Lofar/mdio/src/vhdl/mdio_vitesse_vsc8486_pkg.vhd
+set_global_assignment -name VHDL_FILE /home/kooistra/svnroot/UniBoard_FP7/UniBoard/trunk/Firmware/modules/Lofar/mdio/src/vhdl/mdio.vhd
+set_global_assignment -name VHDL_FILE /home/kooistra/svnroot/UniBoard_FP7/UniBoard/trunk/Firmware/modules/Lofar/mdio/src/vhdl/avs_mdio.vhd
diff --git a/libraries/io/ppsh/hdllib.cfg b/libraries/io/ppsh/hdllib.cfg
index d9d2d980ff0dd757cff6448e5fe2e564381226f6..3e213b5063b9f5c9065ba2383f2b5bfa48b5e034 100644
--- a/libraries/io/ppsh/hdllib.cfg
+++ b/libraries/io/ppsh/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = ppsh_lib
 hdl_lib_uses = common
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     $UNB/Firmware/modules/ppsh/src/vhdl/ppsh.vhd
diff --git a/libraries/io/remu/hdllib.cfg b/libraries/io/remu/hdllib.cfg
index b0d941d4fcf5485fe6ad4d251fe2a5472de0928e..bf02011ec34a79a0d95e3a1b978021e8b277ad9d 100644
--- a/libraries/io/remu/hdllib.cfg
+++ b/libraries/io/remu/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = remu_lib
 hdl_lib_uses = common tech_flash
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     $UNB/Firmware/modules/remu/src/vhdl/remu_reg.vhd
diff --git a/libraries/io/tr_10GbE/hdllib.cfg b/libraries/io/tr_10GbE/hdllib.cfg
index 01bb957bd47f61d27ed10a20ca2f64621f44ac42..1083d199fe0621ffdbf6da114202d8bde7ca0ee2 100644
--- a/libraries/io/tr_10GbE/hdllib.cfg
+++ b/libraries/io/tr_10GbE/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = tr_10GbE_lib
 hdl_lib_uses = common dp diag diagnostics tr_xaui eth
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     $UNB/Firmware/modules/tr_10GbE/src/ip/megawizard/mac_10g/mac_10g.vhd
diff --git a/libraries/io/tr_nonbonded/hdllib.cfg b/libraries/io/tr_nonbonded/hdllib.cfg
index c12ce7a31464892806669f3502c1db2b4c52f8b5..4da4c2ff2bc6e732a3e4005013851a5c1552da99 100644
--- a/libraries/io/tr_nonbonded/hdllib.cfg
+++ b/libraries/io/tr_nonbonded/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = tr_nonbonded_lib
 hdl_lib_uses = common dp diag diagnostics tech_transceiver
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     $UNB/Firmware/modules/tr_nonbonded/tb/vhdl/serializer.vhd
diff --git a/libraries/io/tr_xaui/hdllib.cfg b/libraries/io/tr_xaui/hdllib.cfg
index 3c58797bacbb08570a937eeeaff847acf4865710..eafc2f08b8e4467c621a08b1a7eaf6e23d2d323b 100644
--- a/libraries/io/tr_xaui/hdllib.cfg
+++ b/libraries/io/tr_xaui/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = tr_xaui_lib
 hdl_lib_uses = common dp mdio diagnostics tr_nonbonded unb1_board
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     $UNB/Firmware/modules/tr_xaui/src/vhdl/tr_xaui_pkg.vhd
diff --git a/libraries/technology/fifo/hdllib.cfg b/libraries/technology/fifo/hdllib.cfg
index 17378114eb98140a587067d943de5dbe7431517a..5cd0dc997fcce01c2e7805f4915733b86f9eaf3e 100644
--- a/libraries/technology/fifo/hdllib.cfg
+++ b/libraries/technology/fifo/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = tech_fifo_lib
 hdl_lib_uses = technology ip_stratixiv
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     tech_fifo_component_pkg.vhd
diff --git a/libraries/technology/flash/hdllib.cfg b/libraries/technology/flash/hdllib.cfg
index 0dc7a2e891f6175ff9143a1e8d956688f4a5f362..262900b86c9509c5fc662d74695e7b302621b574 100644
--- a/libraries/technology/flash/hdllib.cfg
+++ b/libraries/technology/flash/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = tech_flash_lib
 hdl_lib_uses = technology ip_stratixiv
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     tech_flash_component_pkg.vhd
diff --git a/libraries/technology/hdllib.cfg b/libraries/technology/hdllib.cfg
index f465a703f61355f482639828b18491f005582335..bacf425f6495ed0fac1f72735df25bf4a6d6a4be 100644
--- a/libraries/technology/hdllib.cfg
+++ b/libraries/technology/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = technology_lib
 hdl_lib_uses =
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     technology_pkg.vhd
diff --git a/libraries/technology/iobuf/hdllib.cfg b/libraries/technology/iobuf/hdllib.cfg
index 77eed63e350590d5fbe6dca53e6f29298c08f0c4..3c4b7d2ebf6b79c3b49389c46e5b40eae62d9f32 100644
--- a/libraries/technology/iobuf/hdllib.cfg
+++ b/libraries/technology/iobuf/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = tech_iobuf_lib
 hdl_lib_uses = technology ip_stratixiv
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     tech_iobuf_component_pkg.vhd
diff --git a/libraries/technology/ip_arria10/hdllib.cfg b/libraries/technology/ip_arria10/hdllib.cfg
index b5b03dee8b9dfaa7842661eef62833e4a415c5ff..7a0970b95ea1bb18b62d6c7e56f894acebb2b52c 100644
--- a/libraries/technology/ip_arria10/hdllib.cfg
+++ b/libraries/technology/ip_arria10/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = ip_arria10_lib
 hdl_lib_uses = technology
 hdl_lib_technology = ip_arria10
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     ip_arria10_ram_crw_crw.vhd
diff --git a/libraries/technology/ip_stratixiv/hdllib.cfg b/libraries/technology/ip_stratixiv/hdllib.cfg
index d9ec4755c68f8736bbd7fa65bd1bf5399f981348..6047869202c7b0d4a2cc72f66b44a2496a6680ab 100644
--- a/libraries/technology/ip_stratixiv/hdllib.cfg
+++ b/libraries/technology/ip_stratixiv/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = ip_stratixiv_lib
 hdl_lib_uses = technology numonyx_m25p128
 hdl_lib_technology = ip_stratixiv
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     ip_stratixiv_ram_crwk_crw.vhd
diff --git a/libraries/technology/ip_stratixiv/phy_xaui/hdllib.cfg b/libraries/technology/ip_stratixiv/phy_xaui/hdllib.cfg
index badc9521252c75f00b4a59c366c29fff15453419..a4038c9c71da317eddd882b08c09a492a99c2fc5 100644
--- a/libraries/technology/ip_stratixiv/phy_xaui/hdllib.cfg
+++ b/libraries/technology/ip_stratixiv/phy_xaui/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = ip_stratixiv_phy_xaui_lib
 hdl_lib_uses = common
 hdl_lib_technology = ip_stratixiv
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 modelsim_compile_ip_files =
     $RADIOHDL/libraries/technology/ip_stratixiv/phy_xaui/compile_ip.tcl
@@ -19,7 +19,13 @@ synth_files =
 test_bench_files = 
     tb_ip_stratixiv_phy_xaui.vhd
 
-synth_copy_files =
+modelsim_search_libraries =
+    stratixiv_pcie_hip_ver stratixiv_pcie_hip work altera_ver lpm_ver sgate_ver altera_mf_ver altera_lnsim_ver stratixiv_hssi_ver stratixiv_ver altera lpm sgate altera_mf altera_lnsim stratixiv_hssi stratixiv
+
+modelsim_copy_files =
+    wave_tb_ip_stratixiv_phy_xaui.do .
+    
+quartus_copy_files =
     
 quartus_vhdl_files = 
 
diff --git a/libraries/technology/ip_stratixiv/tse_sgmii_gx/hdllib.cfg b/libraries/technology/ip_stratixiv/tse_sgmii_gx/hdllib.cfg
index f61dcfeb5113595d07dbc3309896e1ae1532ac3a..d9b6086fb916d1fe6771164028171c6205711837 100644
--- a/libraries/technology/ip_stratixiv/tse_sgmii_gx/hdllib.cfg
+++ b/libraries/technology/ip_stratixiv/tse_sgmii_gx/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = ip_stratixiv_tse_sgmii_gx_lib
 hdl_lib_uses = 
 hdl_lib_technology = ip_stratixiv
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     
diff --git a/libraries/technology/ip_stratixiv/tse_sgmii_lvds/hdllib.cfg b/libraries/technology/ip_stratixiv/tse_sgmii_lvds/hdllib.cfg
index baf68295996d79e4678c6b00f92a02b3e0b64891..c63f06e75edf9afec0d4bd0185119ead87e37396 100644
--- a/libraries/technology/ip_stratixiv/tse_sgmii_lvds/hdllib.cfg
+++ b/libraries/technology/ip_stratixiv/tse_sgmii_lvds/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = ip_stratixiv_tse_sgmii_lvds_lib
 hdl_lib_uses = common
 hdl_lib_technology = ip_stratixiv
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     
@@ -12,7 +12,7 @@ test_bench_files =
     ip_stratixiv_tse_sgmii_lvds.vho
     tb_ip_stratixiv_tse_sgmii_lvds.vhd
 
-synth_copy_files =
+quartus_copy_files =
     $UNB/Firmware/modules/MegaWizard/tse_sgmii_lvds/triple_speed_ethernet-library $RADIOHDL/libraries/technology/ip_stratixiv/tse_sgmii_lvds/triple_speed_ethernet-library
  
 quartus_vhdl_files = 
diff --git a/libraries/technology/ip_virtex4/hdllib.cfg b/libraries/technology/ip_virtex4/hdllib.cfg
index fa37c7fa4a803e00a4cb563c2b1156b288f66bde..2e1c58252f020301cfe5a3ec8443c3712961dc1d 100644
--- a/libraries/technology/ip_virtex4/hdllib.cfg
+++ b/libraries/technology/ip_virtex4/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = ip_virtex4_lib
 hdl_lib_uses = 
 hdl_lib_technology = ip_virtex4
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
         
diff --git a/libraries/technology/memory/hdllib.cfg b/libraries/technology/memory/hdllib.cfg
index a63bb45d38cca241dbc3695922c0bfdc7e6962f9..7df5154baa017840ff244c4a0862602853b2d51b 100644
--- a/libraries/technology/memory/hdllib.cfg
+++ b/libraries/technology/memory/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = tech_memory_lib
 hdl_lib_uses = technology ip_stratixiv ip_arria10 ip_virtex4
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     tech_memory_component_pkg.vhd
diff --git a/libraries/technology/transceiver/hdllib.cfg b/libraries/technology/transceiver/hdllib.cfg
index e086a8cfcb7b7415fe6ab0057bf2ab28bf7ea1a5..10033a9ea52cd7e431da91d0135446335bc63023 100644
--- a/libraries/technology/transceiver/hdllib.cfg
+++ b/libraries/technology/transceiver/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = tech_transceiver_lib
 hdl_lib_uses = technology ip_stratixiv common dp
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     tech_transceiver_component_pkg.vhd
diff --git a/libraries/technology/tse/hdllib.cfg b/libraries/technology/tse/hdllib.cfg
index 14f4e707a05e03d11ceca3d106eba9366ad6ede2..c4484ceafabaec96e3ef7b2a91029d7efd3b118f 100644
--- a/libraries/technology/tse/hdllib.cfg
+++ b/libraries/technology/tse/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = tech_tse_lib
 hdl_lib_uses = technology ip_stratixiv_tse_sgmii_lvds ip_stratixiv_tse_sgmii_gx common dp
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     tech_tse_component_pkg.vhd
diff --git a/libraries/technology/xaui/hdllib.cfg b/libraries/technology/xaui/hdllib.cfg
index df489bd1485a57846622b0f5a863a5ffdd8f06f4..42e6f11d314cdf2e6d8fc2e2b65a34dfddd5c38d 100644
--- a/libraries/technology/xaui/hdllib.cfg
+++ b/libraries/technology/xaui/hdllib.cfg
@@ -3,8 +3,8 @@ hdl_library_clause_name = tech_xaui_lib
 hdl_lib_uses = technology ip_stratixiv_phy_xaui common dp
 hdl_lib_technology = 
 
-build_sim_dir = $HDL_BUILD_DIR
-build_synth_dir = $HDL_BUILD_DIR
+build_dir_sim = $HDL_BUILD_DIR
+build_dir_synth = $HDL_BUILD_DIR
 
 synth_files =
     tech_xaui_component_pkg.vhd
diff --git a/tools/hdltool.cfg b/tools/hdltool.cfg
index 561c06585c9703447726c19568f40d699cab1b5a..81dbecad87677075d4bfa6ee06c65c6d530a9da4 100644
--- a/tools/hdltool.cfg
+++ b/tools/hdltool.cfg
@@ -1,3 +1,3 @@
-sim_tool_name = modelsim
+tool_name_sim = modelsim
+tool_name_synth = quartus
 model_tech_dir = /home/software/Mentor/modeltech
-synth_tool_name = quartus
\ No newline at end of file
diff --git a/tools/hdltool_readme.txt b/tools/hdltool_readme.txt
index 10381540171eca6cc80f348430d3b84e9d56ca48..e2553faf0fb6e1cbf707fe699540f16db70a3c54 100644
--- a/tools/hdltool_readme.txt
+++ b/tools/hdltool_readme.txt
@@ -243,14 +243,15 @@ See also the docstring help text in the Python code:
 
 c) hdltool.cfg key descriptions
 
-- sim_tool_name =
+- tool_name_sim =
     Used as directory name in the build directory, e.g. modelsim.
   
+- tool_name_synth =
+    Used as directory name in the build directory, e.g. quartus.
+    
 - model_tech_dir =
     Used to get the location of the modelsim.ini file, e.g. /home/software/Mentor/modeltech.
   
-- synth_tool_name =
-    Used as directory name in the build directory, e.g. quartus.
 
 d) hdllib.cfg key descriptions 
 
@@ -268,19 +269,19 @@ d) hdllib.cfg key descriptions
     The IP technology that this library is using or targets, e.g. ip_stratixiv for UniBoard1, ip_arria10 for UniBoard2. For generic HDL libraries use ''.
     For simulating systems with multiple FPGA technologies it is also possible to list multiple IP technology names.
 
-- build_sim_dir =
+- build_dir_sim =
     Global root path (e.g. $HDL_BUILD_DIR) or local library path (e.g. '') to the build directory for simulation. The path gets extended with the
-    sim_tool_name from hdltool.cfg.
+    tool_name_sim from hdltool.cfg.
 
-- build_synth_dir =
+- build_dir_synth =
     Global root path (e.g. $HDL_BUILD_DIR) or local library path (e.g. '') to the build directory for simulation. The path gets extended with the
-    synth_tool_name from hdltool.cfg.
+    tool_name_synth from hdltool.cfg.
 
-- sim_copy_files =
-    Copy listed all directories and files for simulation.
+- modelsim_copy_files =
+    Copy listed all directories and files for simulation with Modelsim, used when tool_name_sim = modelsim in hdltool.cfg.
 
-- synth_copy_files =
-    Copy listed all directories and files for synthesis.
+- quartus_copy_files =
+    Copy listed all directories and files for synthesis with Quartus, used when tool_name_synth = quartus in hdltool.cfg.
     
 - synth_files =
     All HDL files that are needed for synthesis. For Modelsim they need to be in compile order and they areplaced in the 'synth_files' project folder.
@@ -347,7 +348,7 @@ or central outside the $RADIOHDL sources directory tree:
   $HDL_BUILD_DIR/quartus/<hdl_lib_name>
                 /modelsim/<hdl_lib_name>
                 
-The choice is made via the build_sim_dir and build_synth_dir keys. If the key is left empty than the build directory will be
+The choice is made via the build_dir_sim and build_dir_synth keys. If the key is left empty than the build directory will be
 local else the key should specify the root path to the central directory e.g.via $HDL_BUILD_DIR. The advantage of the central
 directory build tree is that it can easily be removed (using rm -rf) and recreated (using modelsim_config.py and quartus_config.py).
 For synthesis recreation of targets like sof files can take much time though.
@@ -358,9 +359,9 @@ For synthesis recreation of targets like sof files can take much time though.
 
 a) Creating the Modelsim project files
 
-The binaries for Modelsim get build in a separate directory tree if the build_sim_dir key in the hdllib.cfg contains
+The binaries for Modelsim get build in a separate directory tree if the build_dir_sim key in the hdllib.cfg contains
 an absolute path. Currently the path is set to $HDL_BUILD_DIR = $RADIOHDL/build. By using a local path for the
-build_sim_dir key it is possible to build the library locally in the source directory tree, however using a completely
+build_dir_sim key it is possible to build the library locally in the source directory tree, however using a completely
 separate absolute build tree is more clear. To create the Modelsim project files for all HDL libraries in the $RADIOHDL tree do:
 
   $RADIOHDL> rm -rf build
diff --git a/tools/oneclick/base/quartus_config.py b/tools/oneclick/base/quartus_config.py
index 683f9b54fa6f1e0c91a87f54d9882ff96b65fc3d..380ffabf0d275b95af689492bb53fa70514f7b65 100644
--- a/tools/oneclick/base/quartus_config.py
+++ b/tools/oneclick/base/quartus_config.py
@@ -229,7 +229,7 @@ if __name__ == '__main__':
     qsyn.create_quartus_ip_lib_file()
     
     print ''
-    print 'Copy Quartus directories and files from HDL library source tree to build_synth_dir for all HDL libraries that are found in $%s.' % libRootDir
+    print 'Copy Quartus directories and files from HDL library source tree to build_dir_synth for all HDL libraries that are found in $%s.' % libRootDir
     qsyn.copy_files('synth')
     
     print ''
diff --git a/tools/oneclick/base/hdl_config.py b/tools/oneclick/base/hdl_config.py
index a259f89d52b3e75f85d81d7dbb1f41c422b410b7..614c535d51f57e7375f903c5a8273dd77eb919a6 100644
--- a/tools/oneclick/base/hdl_config.py
+++ b/tools/oneclick/base/hdl_config.py
@@ -141,30 +141,24 @@ class HdlConfig:
         return lib_order
             
 
-    def get_lib_build_dirs(self, build_type, build_subdir=None, lib_dicts=None):
+    def get_lib_build_dirs(self, build_type, lib_dicts=None):
         """Get the tool build directory for all HDL libraries in the specified list of lib_dicts.
         
         The build_type can be:
-            'sim'   uses the 'build_sim_dir'   key in the lib_dict,
-            'synth' uses the 'build_synth_dir' key in the lib_dict
+            'sim'   uses the 'build_dir_sim'   key in the lib_dict,
+            'synth' uses the 'build_dir_synth' key in the lib_dict
             
-        If the build_subdir is not specfied then it defaults to the tool name key value.
-        
         If the build dir key in HDL library config file is '' then
             treat the build dir key as local directory in the HDL library directory.
         else
             treat the build dir key as central directory.
         """
         if lib_dicts==None: lib_dicts=self.libs.dicts
-        if build_type=='sim':
-            build_dir_key = 'build_sim_dir'
-            tool_name_key = 'sim_tool_name'
-        elif build_type=='synth':
-            build_dir_key = 'build_synth_dir'
-            tool_name_key = 'synth_tool_name'
-        else:
+        build_dir_key = 'build_dir_' + build_type
+        tool_name_key = 'tool_name_' + build_type
+        if self.tool.get_key_values(tool_name_key)==None:
             sys.exit('Error : Unknown build type')
-        if build_subdir==None: build_subdir = self.tool.get_key_values(tool_name_key)
+        build_subdir = self.tool.get_key_values(tool_name_key)
         build_dirs = []
         for lib_dict in cm.listify(lib_dicts):
             build_dir = os.path.expandvars(self.libs.get_key_values(build_dir_key, lib_dict))
@@ -206,7 +200,7 @@ class HdlConfig:
         """
         fileName = 'hdl_libraries_' + technologyName + '.txt'                  # use fixed file name format
         if filePath==None:
-            toolSubDir = self.tool.get_key_values('synth_tool_name')
+            toolSubDir = self.tool.get_key_values('tool_name_synth')
             fileNamePath=os.path.join(self.toolRootDir, toolSubDir, fileName)  # default file path
         else:
             fileNamePath=os.path.join(filePath, fileName)                      # specified file path
@@ -214,25 +208,27 @@ class HdlConfig:
         return tech_dict
     
     def copy_files(self, build_type, lib_names=None):
-        """Copy all source directories and source files listed at the synth_copy_files or the sim_copy_files key. The build_type selects the key.
-           the *_copy_files key expects a source and a destination pair per listed directory or file:
+        """Copy all source directories and source files listed at the <tool_name>_copy_files key. The build_type selects the <tool_name>_copy_files key using the
+           tool_name_<build_type> key value from the hdltool.cfg.
+           The <tool_name>_copy_files key expects a source and a destination pair per listed directory or file:
            
-           - The sources need to be specified with absolute path or relative to the HDL library directory
-           - The destinations need to be specified with absolute path or relative to the build_*_dir
+           - The sources need to be specified with absolute path or relative to the HDL library source directory where the hdllib.cfg is stored
+           - The destinations need to be specified with absolute path or relative to HDL library build directory where the project file (e.g. mpf, qpf) gets stored
            
            Arguments:
            - lib_names      : one or more HDL libraries
         """
         if lib_names==None: lib_names=self.lib_names
         lib_dicts = self.libs.get_dicts(key='hdl_lib_name', values=lib_names)
-        if build_type=='sim':   copy_key='sim_copy_files'
-        if build_type=='synth': copy_key='synth_copy_files'
+        tool_name_key = 'tool_name_' + build_type
+        tool_name_value = self.tool.get_key_values(tool_name_key)
+        tool_name_copy_key = tool_name_value + '_copy_files'
         for lib_dict in cm.listify(lib_dicts):
-            if copy_key in lib_dict:
+            if tool_name_copy_key in lib_dict:
                 lib_path = self.libs.get_filePath(lib_dict)
-                build_path = self.get_lib_build_dirs('synth', lib_dicts=lib_dict)
+                build_path = self.get_lib_build_dirs(build_type, lib_dicts=lib_dict)
                 cm.mkdir(build_path)
-                key_values = lib_dict[copy_key].split()
+                key_values = lib_dict[tool_name_copy_key].split()
                 sources = key_values[0::2]
                 destinations = key_values[1::2]
                 file_io = zip(sources, destinations)
@@ -253,6 +249,8 @@ if __name__ == '__main__':
     # 1 = Change a key value in all hdllib.cfg dict files
     # 2 = Insert a new key = value pair in all hdllib.cfg dict files at the specified line number
     # 3 = Insert a new key = value pair in all hdllib.cfg dict files just before an already existing key
+    # 4 = Rename a key in all hdllib.cfg dict files
+    # 5 = Remove a new key = value pair from all hdllib.cfg dict files
     mode = 0
     
     if mode==0:   
@@ -310,13 +308,13 @@ if __name__ == '__main__':
             print 'derive_lib_order = ', hdl.derive_lib_order(hdl.derive_all_use_libs('unb_minimal'))
     
     if mode==1:
-        key = 'build_synth_dir'
+        key = 'build_dir_synth'
         new_value = '$HDL_BUILD_DIR'
         # Read the dictionary info from all HDL tool and library configuration files in the current directory and the sub directories
         libRootDir = 'RADIOHDL'
         hdl = HdlConfig(libRootDir=os.environ[libRootDir], toolRootDir=os.path.expandvars('$RADIOHDL/tools'), libFileName='hdllib.cfg', toolFileName='hdltool.cfg', technologyNames=[])
         for p in hdl.libs.filePathNames:
-             hdl.libs.change_key_in_dict_file(p, key, new_value)
+             hdl.libs.change_key_value_in_dict_file(p, key, new_value)
 
     if mode==2:
         insert_key = 'hdl_lib_technology'
@@ -337,3 +335,20 @@ if __name__ == '__main__':
         hdl = HdlConfig(libRootDir=os.environ[libRootDir], toolRootDir=os.path.expandvars('$RADIOHDL/tools'), libFileName='hdllib.cfg', toolFileName='hdltool.cfg', technologyNames=[])
         for p in hdl.libs.filePathNames:
              hdl.libs.insert_key_in_dict_file_before_another_key(p, insert_key, insert_value, insert_beforeKey)
+
+    if mode==4:
+        old_key = 'synth_copy_files'
+        new_key = 'quartus_copy_files'
+        # Read the dictionary info from all HDL tool and library configuration files in the current directory and the sub directories
+        libRootDir = 'RADIOHDL'
+        hdl = HdlConfig(libRootDir=os.environ[libRootDir], toolRootDir=os.path.expandvars('$RADIOHDL/tools'), libFileName='hdllib.cfg', toolFileName='hdltool.cfg', technologyNames=[])
+        for p in hdl.libs.filePathNames:
+             hdl.libs.rename_key_in_dict_file(p, old_key, new_key)
+             
+    if mode==5:
+        remove_key = 'build_synth_dir'
+        # Read the dictionary info from all HDL tool and library configuration files in the current directory and the sub directories
+        libRootDir = 'RADIOHDL'
+        hdl = HdlConfig(libRootDir=os.environ[libRootDir], toolRootDir=os.path.expandvars('$RADIOHDL/tools'), libFileName='hdllib.cfg', toolFileName='hdltool.cfg', technologyNames=[])
+        for p in hdl.libs.filePathNames:
+             hdl.libs.remove_key_from_dict_file(p, remove_key)